==> infima_client-0.59.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_coverage_summary.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_coverage import CohortCoverage
from ...models.cohort_coverage_error import CohortCoverageError
from ...models.cohort_coverage_not_found import CohortCoverageNotFound
from ...models.cohort_coverage_unauthorized import CohortCoverageUnauthorized
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    year: Union[Unset, int] = UNSET,
    month: Union[Unset, int] = UNSET,
    day: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/coverage".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    params: Dict[str, Any] = {
        "year": year,
        "month": month,
        "day": day,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortCoverage.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = CohortCoverageUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = CohortCoverageNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = CohortCoverageError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    year: Union[Unset, int] = UNSET,
    month: Union[Unset, int] = UNSET,
    day: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        year=year,
        month=month,
        day=day,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    year: Union[Unset, int] = UNSET,
    month: Union[Unset, int] = UNSET,
    day: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    """


    Args:
        year: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        month: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        day: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        year=year,
        month=month,
        day=day,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    year: Union[Unset, int] = UNSET,
    month: Union[Unset, int] = UNSET,
    day: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        year=year,
        month=month,
        day=day,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    year: Union[Unset, int] = UNSET,
    month: Union[Unset, int] = UNSET,
    day: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            year=year,
            month=month,
            day=day,
        )
    ).parsed

==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_coverage_summary.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_coverage import CohortCoverage
from ...models.cohort_coverage_error import CohortCoverageError
from ...models.cohort_coverage_not_found import CohortCoverageNotFound
from ...models.cohort_coverage_unauthorized import CohortCoverageUnauthorized
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/coverage".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    params: Dict[str, Any] = {
        "date.year": dateyear,
        "date.month": datemonth,
        "date.day": dateday,
        "monthBack": month_back,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortCoverage.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = CohortCoverageUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = CohortCoverageNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = CohortCoverageError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    """


    Args:
        dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        month_back: None

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortCoverage,
        CohortCoverageUnauthorized,
        CohortCoverageNotFound,
        CohortCoverageError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )
    ).parsed
